@@ -212,7 +212,7 @@
 #'@references Van Buuren, S., Groothuis-Oudshoorn, K. (2011). \code{mice}:
 #'Multivariate Imputation by Chained Equations in \code{R}. \emph{Journal of
 #'Statistical Software}, \bold{45}(3), 1-67.
-#'\url{http://www.jstatsoft.org/v45/i03/}
+#'\url{https://www.jstatsoft.org/v45/i03/}
 #'
 #'Van Buuren, S. (2018). 
 #'\href{https://stefvanbuuren.name/fimd/sec-FCS.html#sec:MICE}{\emph{Flexible Imputation of Missing Data. Second Edition.}}
@@ -269,8 +269,9 @@ mice <- function(data, m = 5,
   call <- match.call()
   if (!is.na(seed)) set.seed(seed)
   
-  # check form of data 
+  # check form of data and m
   data <- check.dataform(data)
+  m <- check.m(m)
   
   # determine input combination: predictorMatrix, blocks, formulas
   mp <- missing(predictorMatrix)
