@@ -15,7 +15,7 @@ IntegerVector matcher(NumericVector obs, NumericVector mis, int k) {
   // SvB 26/01/2014
 
   // declarations
-  int j;
+  int jj;
   int n1 = obs.size();
   int n0 = mis.size();
   double dk = 0; 
@@ -40,25 +40,40 @@ IntegerVector matcher(NumericVector obs, NumericVector mis, int k) {
       // calculate the distance and add noise to break ties
       d2 = runif(n1, 0, small);
       dk = mis[i];
-      for (int k = 0; k < n1; k++) d[k] = std::abs(obs[k] - dk) + d2[k];
+      for (int j = 0; j < n1; j++) d[j] = std::abs(obs[j] - dk) + d2[j];
       
       // find the k'th lowest value in d
       for (int j = 0; j < n1; j++) d2[j] = d[j];
-      std::nth_element (d2.begin(), d2.begin()+k-1, d2.end());
+      std::nth_element (d2.begin(), d2.begin() + k - 1, d2.end());
 
       // find index of donor which[i]
       dk = d2[k-1];
       count = 0;
       goal = (int) which[i];
-      for (j = 0; j < n1; j++) {
-          if (d[j] <= dk) count++;
+      for (jj = 0; jj < n1; jj++) {
+          if (d[jj] <= dk) count++;
           if (count == goal) break;
       }
       
       // and store the result
-      matched[i] = j;
+      matched[i] = jj;
   }
   
   // increase index to offset 1
   return matched + 1;
 }
+
+
+static R_CallMethodDef callMethods[]  = {
+  {"matcher", (DL_FUNC) &matcher, 3},
+  {NULL, NULL, 0}
+};
+
+void attribute_visible R_init_mice(DllInfo *dll)
+{
+  R_registerRoutines(dll, NULL, callMethods, NULL,
+                     NULL);
+  R_useDynamicSymbols(dll, FALSE);
+  R_forceSymbols(dll, TRUE);
+}
+
